==> tt-rss-1.3.2.tgz: tt-rss/localized_schema.php <==
<?
	/* 
	 * This is a dummy plug for gettext to know we have some translatable strings in the schema.
	 *	This file is not otherwise used.	 
	 */

	# filters

	__("Title");
	__("Title or Content");
	__("Link");
	__("Content");
	__("Article Date");

	__("Filter article");
	__("Mark as read");
	__("Set starred");
	__("Publish article");
	__("Assign tags");
	__("Assign label");

	# prefs

	__("General");

	__("Allow duplicate posts");
	__("This option is useful when you are reading several planet-type aggregators with partially colliding userbase. When disabled, it forces same posts from different feeds to appear only once.");
	__("Default interval between feed updates (in minutes)");
	__("Enable e-mail digest");
	__("This option enables sending daily digest of new (and unread) headlines on your configured e-mail address");
	__("Purge old posts after this number of days (0 - disables)");
	__("Update post on checksum change");
	__("Mark articles in e-mail digest as read");

	__("Interface");

	__("Combined feed display");
	__("Display expanded list of feed articles, instead of separate displays for headlines and article content");
	__("Default article limit");
	__("Default limit for articles to display, any custom number you like (0 - disables).");
	__("Enable feed categories");
	__("Enable search toolbar");
	__("Hide feeds with no unread messages");
	__("Mark articles as read automatically");
	__("This option enables marking articles as read automatically in combined mode (except for Fresh articles feed) while you scroll article list.");
	__("On catchup show next feed");
	__("When \"Mark as read\" button is clicked in toolbar, automatically open next feed with unread articles.");
	__("Open article links in new browser window");
	__("Reverse headline order (oldest first)");
	__("Show content preview in headlines list");
	__("Sort feeds by unread articles count");
	__("User stylesheet URL");
	__("Link to user stylesheet to override default style, disabled if empty.");
	__("Maximum age of fresh articles (in hours)");
	__("Hide feedlist");
	__("This option hides feedlist and allows it to be toggled on the fly, useful for small screens.");
	__("Group headlines in virtual feeds");
	__("When this option is enabled, headlines in Special feeds and Labels are grouped by feeds");

	__("Advanced");

	__("Blacklisted tags");
	__("When auto-detecting tags in articles these tags will not be applied (comma-separated list).");
	__("Confirm marking feed as read");
	__("Enable feed icons");
	__("Enable labels");
	__("Experimental support for virtual feeds based on user crafted SQL queries. This feature is highly experimental and at this point not user friendly. Use with caution.");
	__("Long date format");
	__("Set articles as unread on update");
	__("Short date format");
	__("Show additional information in feedlist");
	__("Strip unsafe tags from articles");
	__("Strip all but most common HTML tags when reading articles.");
	__("Use more accessible date/time format for headlines");
	__("Automatically expand articles in combined mode");
	__("Purge unread articles");
	__("Show special feeds when hiding read feeds");
	__("Prefer more accurate feedlist counters to UI speed");
	__("Enable inline MP3 player");
	__("Enable the Flash-based XSPF Player to play MP3-format podcast enclosures.");
	__("Do not show images in articles");

?>

==> tt-rss-1.3.3p3.tgz: tt-rss/localized_schema.php <==
<?
	/* 
	 * This is a dummy plug for gettext to know we have some translatable strings in the schema.
	 *	This file is not otherwise used.	 
	 */

	# filters

	__("Title");
	__("Title or Content");
	__("Link");
	__("Content");
	__("Article Date");

	__("Filter article");
	__("Mark as read");
	__("Set starred");
	__("Publish article");
	__("Assign tags");
	__("Assign label");

	# prefs

	__("General");

	__("Allow duplicate posts");
	__("This option is useful when you are reading several planet-type aggregators with partially colliding userbase. When disabled, it forces same posts from different feeds to appear only once.");
	__("Default interval between feed updates (in minutes)");
	__("Enable e-mail digest");
	__("This option enables sending daily digest of new (and unread) headlines on your configured e-mail address");
	__("Purge old posts after this number of days (0 - disables)");
	__("Update post on checksum change");
	__("Mark articles in e-mail digest as read");
	__("Enable offline reading");
	__("Synchronize new articles for offline reading using Google Gears.");

	__("Interface");

	__("Combined feed display");
	__("Display expanded list of feed articles, instead of separate displays for headlines and article content");
	__("Default article limit");
	__("Default limit for articles to display, any custom number you like (0 - disables).");
	__("Enable feed categories");
	__("Enable search toolbar");
	__("Hide feeds with no unread messages");
	__("Mark articles as read automatically");
	__("This option enables marking articles as read automatically in combined mode (except for Fresh articles feed) while you scroll article list.");
	__("On catchup show next feed");
	__("When \"Mark as read\" button is clicked in toolbar, automatically open next feed with unread articles.");
	__("Open article links in new browser window");
	__("Reverse headline order (oldest first)");
	__("Show content preview in headlines list");
	__("Sort feeds by unread articles count");
	__("User stylesheet URL");
	__("Link to user stylesheet to override default style, disabled if empty.");
	__("Maximum age of fresh articles (in hours)");
	__("Hide feedlist");
	__("This option hides feedlist and allows it to be toggled on the fly, useful for small screens.");
	__("Group headlines in virtual feeds");
	__("When this option is enabled, headlines in Special feeds and Labels are grouped by feeds");

	__("Advanced");

	__("Blacklisted tags");
	__("When auto-detecting tags in articles these tags will not be applied (comma-separated list).");
	__("Confirm marking feed as read");
	__("Enable feed icons");
	__("Enable labels");
	__("Experimental support for virtual feeds based on user crafted SQL queries. This feature is highly experimental and at this point not user friendly. Use with caution.");
	__("Long date format");
	__("Set articles as unread on update");
	__("Short date format");
	__("Show additional information in feedlist");
	__("Strip unsafe tags from articles");
	__("Strip all but most common HTML tags when reading articles.");
	__("Use more accessible date/time format for headlines");
	__("Automatically expand articles in combined mode");
	__("Purge unread articles");
	__("Show special feeds when hiding read feeds");
	__("Prefer more accurate feedlist counters to UI speed");
	__("Enable inline MP3 player");
	__("Enable the Flash-based XSPF Player to play MP3-format podcast enclosures.");
	__("Do not show images in articles");

?>
